ALTER TABLE mantenimiento
	ADD COLUMN nProgramacion_Id INT;

USE `vpsfmsac_inspeccionesmodaservice`;
DROP procedure IF EXISTS `programacion_listar`;

USE `vpsfmsac_inspeccionesmodaservice`;
DROP procedure IF EXISTS `vpsfmsac_inspeccionesmodaservice`.`programacion_listar`;
;

DELIMITER $$
USE `vpsfmsac_inspeccionesmodaservice`$$
CREATE DEFINER=`root`@`localhost` PROCEDURE `programacion_listar`(IN `pProgramacion_Id` INT(11))
BEGIN
	IF pProgramacion_Id = 0 THEN
		SELECT
			p.Programacion_Id,
			p.dProFecha,
			p.nProEquipo_Id,
			p.nProTecnico_Id,
			p.nProPlantilla_Id,
			p.dProFecha_Act,
			p.nProUsuario_Id,
			p.nProEstado,
			p.nProEliminado,
            e.sEqActivoFijo,
            u.sUsuNombre,
            pl.sPlaNombre
		FROM programacion p
        INNER JOIN equipos e ON p.nProEquipo_Id = e.Equipo_Id
        INNER JOIN usuarios u ON p.nProTecnico_Id = u.nUsuId
        INNER JOIN plantillas pl ON p.nProPlantilla_Id = pl.Plantilla_Id
        WHERE p.nProEliminado = 0;
	ELSE
		SELECT
			p.Programacion_Id,
			p.dProFecha,
			p.nProEquipo_Id,
			p.nProTecnico_Id,
			p.nProPlantilla_Id,
			p.dProFecha_Act,
			p.nProUsuario_Id,
			p.nProEstado,
			p.nProEliminado,
            e.sEqActivoFijo,
            u.sUsuNombre,
            pl.sPlaNombre
		FROM programacion p
        INNER JOIN equipos e ON p.nProEquipo_Id = e.Equipo_Id
        INNER JOIN usuarios u ON p.nProTecnico_Id = u.nUsuId
        INNER JOIN plantillas pl ON p.nProPlantilla_Id = pl.Plantilla_Id
        WHERE p.Programacion_Id = pProgramacion_Id;
    END IF;
END$$

DELIMITER ;
;


USE `vpsfmsac_inspeccionesmodaservice`;
DROP procedure IF EXISTS `programacion_eliminar`;

USE `vpsfmsac_inspeccionesmodaservice`;
DROP procedure IF EXISTS `vpsfmsac_inspeccionesmodaservice`.`programacion_eliminar`;
;

DELIMITER $$
USE `vpsfmsac_inspeccionesmodaservice`$$
CREATE DEFINER=`root`@`localhost` PROCEDURE `programacion_eliminar`(IN `pProgramacion_Id` INT(11))
BEGIN
	UPDATE programacion SET
        nProEstado = 0
        WHERE Programacion_Id = pProgramacion_Id;
END$$

DELIMITER ;
;


USE `vpsfmsac_inspeccionesmodaservice`;
DROP procedure IF EXISTS `list_table_progMantenimiento`;

USE `vpsfmsac_inspeccionesmodaservice`;
DROP procedure IF EXISTS `vpsfmsac_inspeccionesmodaservice`.`list_table_progMantenimiento`;
;

DELIMITER $$
USE `vpsfmsac_inspeccionesmodaservice`$$
CREATE DEFINER=`root`@`localhost` PROCEDURE `list_table_progMantenimiento`()
BEGIN
	SELECT
	  e.Equipo_Id,
      e.sEqActivoFijo,
      m.sManOdometroActual,
      c.*,
	  COALESCE(m.sManMantActual, '') AS Mantenimiento,
	  COALESCE(DATE_FORMAT(m.dManFecha_Act, '%d-%m-%Y'), '') AS dManFecha_Act,
      CASE 
		WHEN e.nEqTipo = 1 THEN 'GE'
        WHEN e.nEqTipo = 2 THEN 'Torre'
        WHEN e.nEqTipo = 3 THEN 'Compresor'
        WHEN e.nEqTipo = 4 THEN 'Rodillo compactador'
      END as Tipo,
      CASE
		#WHEN m.sManMantActual IS NULL THEN 'SMP-250'
        # otra condición para cuando m.sManMantActual es SMP-250
        WHEN m.sManMantActual = 'SMP-250' AND m.sManMantAnterior = 'SMP-1000' THEN 'SMP-500'
        WHEN m.sManMantActual = 'SMP-250' AND m.sManMantAnterior = 'SMP-500' AND m.sManOdometroActual not between 2751 and  2999 THEN 'SMP-1000'
        WHEN m.sManMantActual = 'SMP-250' AND m.sManMantAnterior = 'SMP-500' AND m.sManOdometroActual between 2751 and  2999 THEN 'SMP-3000'
        WHEN m.sManMantActual = 'SMP-250' AND m.sManMantAnterior = 'SMP-500' AND m.sManOdometroActual between 5751 and  5999 THEN 'SMP-6000'
        WHEN m.sManMantActual = 'SMP-250' AND siguiente_mantenimiento(m.sManOdometroActual) = 1 THEN 'SMP-1000'
        WHEN m.sManMantActual = 'SMP-250' AND siguiente_mantenimiento(m.sManOdometroActual) = 0 THEN 'SMP-500'
        WHEN m.sManMantActual in('SMP-500','SMP-1000','SMP-3000','SMP-6000') THEN 'SMP-250'
      END as Sgte
	FROM equipos e
    INNER JOIN detalle_contrato dc
    ON dc.sDetConCodigo = e.sEqActivoFijo
    INNER JOIN contrato c
    ON c.Contrato_Id = dc.nContrato_Id
    
	LEFT JOIN mantenimiento m    
	ON e.Equipo_Id = m.nManEquipo_Id
	WHERE 
    c.dConFechaTermino > now() AND
    (m.Mantenimiento_Id = (
	  SELECT MAX(Mantenimiento_Id)
	  FROM mantenimiento
	  WHERE nManEquipo_Id = e.Equipo_Id
	  )
	  OR m.Mantenimiento_Id IS NULL)
	ORDER BY
		CASE
			WHEN m.dManFecha_Act IS NOT NULL AND m.dManFecha_Act <> '' THEN 0
			ELSE 1
		END,
		m.dManFecha_Act;
END$$

DELIMITER ;
;


USE `vpsfmsac_inspeccionesmodaservice`;
DROP procedure IF EXISTS `list_equipo_progMantenimiento`;

DELIMITER $$
USE `vpsfmsac_inspeccionesmodaservice`$$
CREATE PROCEDURE `list_equipo_progMantenimiento` ()
BEGIN
	SELECT e.*, p.Programacion_Id, p.nProTecnico_Id FROM programacion p
		INNER JOIN equipos e
		ON p.nProEquipo_Id=e.Equipo_Id
		WHERE p.nProEstado = 1;
END$$

DELIMITER ;


USE `vpsfmsac_inspeccionesmodaservice`;
DROP procedure IF EXISTS `list_equipo_sin_progMantenimiento`;

DELIMITER $$
USE `vpsfmsac_inspeccionesmodaservice`$$
CREATE PROCEDURE `list_equipo_sin_progMantenimiento` ()
BEGIN
	SELECT e.* FROM equipos e
		WHERE e.Equipo_Id NOT IN (
			SELECT nProEquipo_Id FROM programacion WHERE nProEstado = 1
		);
END$$

DELIMITER ;


USE `vpsfmsac_inspeccionesmodaservice`;
DROP procedure IF EXISTS `vpsfmsac_inspeccionesmodaservice`.`mant_crear`;
;

DELIMITER $$
USE `vpsfmsac_inspeccionesmodaservice`$$
CREATE DEFINER=`root`@`localhost` PROCEDURE `mant_crear`(IN `pnManEquipo_Id` INT(11), IN `pnManTecnico_Id` INT(11), IN `psManOdometroAnterior` VARCHAR(20), IN `psManMantAnterior` VARCHAR(20), IN `psManOdometroActual` VARCHAR(20), IN `psManMantActual` VARCHAR(20), IN `psManFirmaTecnico` VARCHAR(150), IN `psManFirmaCliente` VARCHAR(150), IN `pnManUsuario_Id` INT(11), IN `pnManPlantilla_Id` INT(11), IN `pProgramacion_Id` INT, OUT `pMantenimiento_Id` INT)
BEGIN
	INSERT INTO mantenimiento
	(`nManEquipo_Id`, `nManTecnico_Id`, `sManOdometroAnterior`, `sManMantAnterior`, `sManOdometroActual`, `sManMantActual`, `sManFirmaTecnico`, `sManFirmaCliente`, `dManFecha_Act`, `nManUsuario_Id`, `nManEstado`, `nManEliminado`, `nManPlantilla_Id`)
    values
    (pnManEquipo_Id, pnManTecnico_Id, psManOdometroAnterior, psManMantAnterior, psManOdometroActual, psManMantActual, psManFirmaTecnico, psManFirmaCliente, now(), pnManUsuario_Id, 1, 0, pnManPlantilla_Id);
    
    IF pProgramacion_Id != 0 THEN
		UPDATE programacion SET nProEstado = 2 WHERE Programacion_Id=pProgramacion_Id;
    END IF;
    
	SET pMantenimiento_Id = LAST_INSERT_ID();
    SELECT IFNULL(pMantenimiento_Id, -99) as Mantenimiento_Id;
END$$

DELIMITER ;
;

USE `vpsfmsac_inspeccionesmodaservice`;
DROP procedure IF EXISTS `mant_listar`;

USE `vpsfmsac_inspeccionesmodaservice`;
DROP procedure IF EXISTS `vpsfmsac_inspeccionesmodaservice`.`mant_listar`;
;

DELIMITER $$
USE `vpsfmsac_inspeccionesmodaservice`$$
CREATE DEFINER=`root`@`localhost` PROCEDURE `mant_listar`(IN `pMantenimiento_Id` INT(11))
BEGIN
	IF pMantenimiento_Id = 0 THEN
		SELECT
			m.Mantenimiento_Id,
			m.nManEquipo_Id,
			m.nManTecnico_Id,
            m.sManOdometroAnterior,
			m.sManMantAnterior,
			m.sManOdometroActual,
			m.sManMantActual,
			m.sManFirmaTecnico,
			m.sManFirmaCliente,
			m.dManFecha_Act,
			m.nManUsuario_Id,
			m.nManEstado,
            m.nManPlantilla_Id,
			m.nManEliminado,
            e.sEqActivoFijo,
            e.sEqSerie,
            e.sEqModelo,
            m.nProgramacion_Id,
            CASE e.nEqTipo
				WHEN 1 THEN 'GE'
				WHEN 2 THEN 'Torre'
				WHEN 3 THEN 'Compresor'
                WHEN 4 THEN 'Rodillo compactador'
				ELSE ''
			END as Tipo,
            u.sUsuNombre
        FROM mantenimiento m
        INNER JOIN equipos e ON m.nManEquipo_Id = e.Equipo_Id
        INNER JOIN usuarios u ON m.nManTecnico_Id = u.nUsuId
		WHERE m.nManEstado = 1 AND m.nManEliminado = 0;
    ELSE
		SELECT
			m.Mantenimiento_Id,
			m.nManEquipo_Id,
			m.nManTecnico_Id,
            m.sManOdometroAnterior,
			m.sManMantAnterior,
			m.sManOdometroActual,
			m.sManMantActual,
			m.sManFirmaTecnico,
			m.sManFirmaCliente,
			m.dManFecha_Act,
			m.nManUsuario_Id,
			m.nManEstado,
            m.nManPlantilla_Id,
			m.nManEliminado,
            e.sEqActivoFijo,
            e.sEqSerie,
            e.sEqModelo,
            m.nProgramacion_Id,
            CASE e.nEqTipo
				WHEN 1 THEN 'GE'
				WHEN 2 THEN 'Torre'
				WHEN 3 THEN 'Compresor'
                WHEN 4 THEN 'Rodillo compactador'
				ELSE ''
			END as Tipo,
            u.sUsuNombre
        FROM mantenimiento m
        INNER JOIN equipos e ON m.nManEquipo_Id = e.Equipo_Id
        INNER JOIN usuarios u ON m.nManTecnico_Id = u.nUsuId
		WHERE m.nManEstado = 1 AND m.nManEliminado = 0 AND m.Mantenimiento_Id = pMantenimiento_Id;
    END IF;
END$$

DELIMITER ;
;


USE `vpsfmsac_inspeccionesmodaservice`;
DROP procedure IF EXISTS `mant_editar`;

USE `vpsfmsac_inspeccionesmodaservice`;
DROP procedure IF EXISTS `vpsfmsac_inspeccionesmodaservice`.`mant_editar`;
;

DELIMITER $$
USE `vpsfmsac_inspeccionesmodaservice`$$
CREATE DEFINER=`root`@`localhost` PROCEDURE `mant_editar`(IN `pnManEquipo_Id` INT(11), IN `pnManTecnico_Id` INT(11), IN `psManOdometroAnterior` VARCHAR(20), IN `psManMantAnterior` VARCHAR(20), IN `psManOdometroActual` VARCHAR(20), IN `psManMantActual` VARCHAR(20), IN `psManFirmaTecnico` VARCHAR(150), IN `psManFirmaCliente` VARCHAR(150), IN `pnManUsuario_Id` INT(11), IN `pMantenimiento_Id` INT(11), IN `pnManPlantilla_Id` INT(11), IN `pProgramacion_Id` INT, IN `pProgramacion_Id_old` INT)
BEGIN
	UPDATE mantenimiento
    SET
	`nManEquipo_Id` = pnManEquipo_Id,
    `nManTecnico_Id` = pnManTecnico_Id,
    `sManOdometroAnterior` = psManOdometroAnterior,
    `sManMantAnterior` = psManMantAnterior,
    `sManOdometroActual` = psManOdometroActual,
    `sManMantActual` = psManMantActual,
    `sManFirmaTecnico` = psManFirmaTecnico,
    `sManFirmaCliente` = psManFirmaCliente,
    `dManFecha_Act` = now(),
    `nManUsuario_Id` = pnManUsuario_Id,
    `nManEstado` = 1,
    `nManEliminado` = 0,
    `nManPlantilla_Id` = pnManPlantilla_Id,
    `nProgramacion_Id` = pProgramacion_Id
    WHERE Mantenimiento_Id = pMantenimiento_Id;
    
    IF pProgramacion_Id != pProgramacion_Id_old THEN
		# actualizar estado de programacion que estaba inicialmente
		UPDATE programacion SET nProEstado = 1 WHERE Programacion_Id=pProgramacion_Id_old;
        
        IF pProgramacion_Id!=0 THEN
			UPDATE programacion SET nProEstado = 2 WHERE Programacion_Id=pProgramacion_Id;
        END IF;
        
    END IF;
END$$

DELIMITER ;
;